==> duiba-live-supplier-center-api-0.0.1-20220108.025530-20-sources.jar: cn/com/duiba/supplier/center/api/params/SupplierPageParam.java <==
package cn.com.duiba.supplier.center.api.params;

import java.io.Serializable;

/**
 * @date:2022/1/7 11:42
 * @author:zhaozhanghai
 * @Description:
 */
public class SupplierPageParam implements Serializable {
    private static final long serialVersionUID = -6688389678284513822L;
    /**
     * 供应商id
     */
    private Long supplierId;


    /**
     * 供应商name
     */

    private String supplierName;

    /**
     *供应商类型 0-自营 1-pop
     */

    private Integer supplierType;

    //    供应商状态:0关闭1开启
    private Integer supplierStatus;

    //    入驻开始时间
    private String startDate;

    //    入驻结束时间
    private String endDate;

    //    页码
    private Long pageNo;
    //    条数
    private Long pageSize;
    /**
     * 分页最大偏移量
     */
    private Long maxOffset;

    public SupplierPageParam() {
        this.pageSize = 20L;
        this.pageNo = 1L;
    }

    public Long getSupplierId() {
        return supplierId;
    }

    public void setSupplierId(Long supplierId) {
        this.supplierId = supplierId;
    }

    public String getSupplierName() {
        return supplierName;
    }

    public void setSupplierName(String supplierName) {
        this.supplierName = supplierName;
    }

    public Integer getSupplierType() {
        return supplierType;
    }

    public void setSupplierType(Integer supplierType) {
        this.supplierType = supplierType;
    }

    public Integer getSupplierStatus() {
        return supplierStatus;
    }

    public void setSupplierStatus(Integer supplierStatus) {
        this.supplierStatus = supplierStatus;
    }

    public String getStartDate() {
        return startDate;
    }

    public void setStartDate(String startDate) {
        this.startDate = startDate;
    }

    public String getEndDate() {
        return endDate;
    }

    public void setEndDate(String endDate) {
        this.endDate = endDate;
    }

    public Long getPageNo() {
        return pageNo;
    }

    public void setPageNo(Long pageNo) {
        this.pageNo = pageNo;
    }

    public Long getPageSize() {
        return pageSize;
    }

    public void setPageSize(Long pageSize) {
        this.pageSize = pageSize;
    }

    public Long getMaxOffset() {
        return maxOffset;
    }

    public void setMaxOffset(Long maxOffset) {
        this.maxOffset = maxOffset;
    }
}

==> duiba-live-supplier-center-api-0.0.2-20220114.030437-4-sources.jar: cn/com/duiba/supplier/center/api/params/SupplierPageParam.java <==
package cn.com.duiba.supplier.center.api.params;

import cn.com.duiba.supplier.center.api.base.BasePage;

import java.io.Serializable;

/**
 * @date:2022/1/7 11:42
 * @author:zhaozhanghai
 * @Description:
 */
public class SupplierPageParam extends BasePage implements Serializable {
    private static final long serialVersionUID = -6688389678284513822L;
    /**
     * 供应商id
     */
    private Long supplierId;


    /**
     * 供应商name
     */

    private String supplierName;

    /**
     *供应商类型 0-自营 1-pop
     */

    private Integer supplierType;

    //    供应商状态:0关闭1开启
    private Integer supplierStatus;

    //    入驻开始时间
    private String startDate;

    //    入驻结束时间
    private String endDate;

    public SupplierPageParam() {
        super.setPageSize(20L);
        super.setPageNo(1L);
    }

    public Long getSupplierId() {
        return supplierId;
    }

    public void setSupplierId(Long supplierId) {
        this.supplierId = supplierId;
    }

    public String getSupplierName() {
        return supplierName;
    }

    public void setSupplierName(String supplierName) {
        this.supplierName = supplierName;
    }

    public Integer getSupplierType() {
        return supplierType;
    }

    public void setSupplierType(Integer supplierType) {
        this.supplierType = supplierType;
    }

    public Integer getSupplierStatus() {
        return supplierStatus;
    }

    public void setSupplierStatus(Integer supplierStatus) {
        this.supplierStatus = supplierStatus;
    }

    public String getStartDate() {
        return startDate;
    }

    public void setStartDate(String startDate) {
        this.startDate = startDate;
    }

    public String getEndDate() {
        return endDate;
    }

    public void setEndDate(String endDate) {
        this.endDate = endDate;
    }


}
